@@ -3,7 +3,7 @@ bai.out <- function(rwl, diam = NULL) {
     if(!is.null(diam)) {
         if(ncol(rwl) != nrow(diam))
             stop("dimension problem: ", "'ncol(rw)' != 'nrow(diam)'")
-        if(!all(diam[, 1] %in% colnames(rwl)))
+        if(!all(diam[, 1] %in% names(rwl)))
             stop("series ids in 'diam' and 'rwl' do not match")
         diam.vec <- diam[, 2]
     }
