@@ -1,7 +1,7 @@
 `tbrm` <- function(x, C=9)
 {
-    x <- as.double(x[!is.na(x)])
+    y <- as.double(x[!is.na(x)])
     .C(dplR.tbrm,
-       x, as.integer(length(x)), as.double(C),
+       y, as.integer(length(y)), as.double(C),
        result=NaN, NAOK=TRUE, DUP=FALSE)$result
 }
